@@ -67,11 +67,6 @@ IconItem::IconItem(QQuickItem *parent)
     connect(KIconLoader::global(), &KIconLoader::iconLoaderSettingsChanged,
             this, &IconItem::updateImplicitSize);
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 10, 0)
-    connect(this, &QQuickItem::enabledChanged,
-            this, &IconItem::onEnabledChanged);
-#endif
-
     connect(this, &IconItem::implicitWidthChanged, this, &IconItem::implicitWidthChanged2);
     connect(this, &IconItem::implicitHeightChanged, this, &IconItem::implicitHeightChanged2);
 
@@ -163,8 +158,14 @@ void IconItem::setSource(const QVariant &source)
         }
 
         if (!localFile.isEmpty()) {
-            m_icon = QIcon();
-            m_imageIcon = QImage(localFile);
+            if (sourceString.endsWith(QLatin1String(".svg")) ||
+                sourceString.endsWith(QLatin1String(".svgz"))) {
+                m_icon = QIcon(localFile);
+                m_imageIcon = QImage();
+            } else {
+                m_icon = QIcon();
+                m_imageIcon = QImage(localFile);
+            }
             m_svgIconName.clear();
             delete m_svgIcon;
             m_svgIcon = nullptr;
@@ -555,6 +556,13 @@ void IconItem::iconLoaderIconChanged(int group)
     schedulePixmapUpdate();
 }
 
+void IconItem::windowVisibleChanged(bool visible)
+{
+    if (visible) {
+        m_blockNextAnimation = true;
+    }
+}
+
 void IconItem::schedulePixmapUpdate()
 {
     polish();
@@ -644,11 +652,9 @@ void IconItem::loadPixmap()
     //don't animate initial setting
     bool animated = (m_animated || m_allowNextAnimation) && !m_oldIconPixmap.isNull() && !m_sizeChanged && !m_blockNextAnimation;
 
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 9, 0))
     if (QQuickWindow::sceneGraphBackend() == QLatin1String("software")) {
         animated = false;
     }
-#endif
 
     if (animated) {
         m_animValue = 0.0;
@@ -668,12 +674,18 @@ void IconItem::itemChange(ItemChange change, const ItemChangeData &value)
 {
     if (change == ItemVisibleHasChanged && value.boolValue) {
         m_blockNextAnimation = true;
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
     } else if (change == ItemEnabledHasChanged) {
         onEnabledChanged();
-#endif
     } else if (change == ItemSceneChange && value.window) {
+        if (m_window) {
+            disconnect(m_window.data(), &QWindow::visibleChanged, this, &IconItem::windowVisibleChanged);
+        }
+        m_window = value.window;
+        if (m_window) {
+            connect(m_window.data(), &QWindow::visibleChanged, this, &IconItem::windowVisibleChanged);
+        }
         schedulePixmapUpdate();
+
     }
 
     QQuickItem::itemChange(change, value);
