@@ -46,23 +46,23 @@ const char ThemePrivate::systemColorsTheme[] = "internal-system-colors";
 EffectWatcher *ThemePrivate::s_backgroundContrastEffectWatcher = nullptr;
 #endif
 
-ThemePrivate *ThemePrivate::globalTheme = 0;
+ThemePrivate *ThemePrivate::globalTheme = nullptr;
 QAtomicInt ThemePrivate::globalThemeRefCount = QAtomicInt();
 QHash<QString, ThemePrivate *> ThemePrivate::themes = QHash<QString, ThemePrivate *>();
 QHash<QString, QAtomicInt> ThemePrivate::themesRefCount = QHash<QString, QAtomicInt>();
 
 ThemePrivate::ThemePrivate(QObject *parent)
     : QObject(parent),
-      colorScheme(QPalette::Active, KColorScheme::Window, KSharedConfigPtr(0)),
-      selectionColorScheme(QPalette::Active, KColorScheme::Selection, KSharedConfigPtr(0)),
-      buttonColorScheme(QPalette::Active, KColorScheme::Button, KSharedConfigPtr(0)),
-      viewColorScheme(QPalette::Active, KColorScheme::View, KSharedConfigPtr(0)),
-      complementaryColorScheme(QPalette::Active, KColorScheme::Complementary, KSharedConfigPtr(0)),
+      colorScheme(QPalette::Active, KColorScheme::Window, KSharedConfigPtr(nullptr)),
+      selectionColorScheme(QPalette::Active, KColorScheme::Selection, KSharedConfigPtr(nullptr)),
+      buttonColorScheme(QPalette::Active, KColorScheme::Button, KSharedConfigPtr(nullptr)),
+      viewColorScheme(QPalette::Active, KColorScheme::View, KSharedConfigPtr(nullptr)),
+      complementaryColorScheme(QPalette::Active, KColorScheme::Complementary, KSharedConfigPtr(nullptr)),
       defaultWallpaperTheme(QStringLiteral(DEFAULT_WALLPAPER_THEME)),
       defaultWallpaperSuffix(QStringLiteral(DEFAULT_WALLPAPER_SUFFIX)),
       defaultWallpaperWidth(DEFAULT_WALLPAPER_WIDTH),
       defaultWallpaperHeight(DEFAULT_WALLPAPER_HEIGHT),
-      pixmapCache(0),
+      pixmapCache(nullptr),
       cacheSize(0),
       cachesToDiscard(NoCache),
       compositingActive(KWindowSystem::self()->compositingActive()),
@@ -71,9 +71,9 @@ ThemePrivate::ThemePrivate(QObject *parent)
       useGlobal(true),
       hasWallpapers(false),
       fixedName(false),
-      backgroundContrast(0),
-      backgroundIntensity(0),
-      backgroundSaturation(0),
+      backgroundContrast(qQNaN()),
+      backgroundIntensity(qQNaN()),
+      backgroundSaturation(qQNaN()),
       backgroundContrastEnabled(true),
       apiMajor(1),
       apiMinor(0),
@@ -134,8 +134,7 @@ ThemePrivate::ThemePrivate(QObject *parent)
 ThemePrivate::~ThemePrivate()
 {
     saveSvgElementsCache();
-    QHash<QString, FrameData*> data = FrameSvgPrivate::s_sharedFrames.take(this);
-    qDeleteAll(data);
+    FrameSvgPrivate::s_sharedFrames.remove(this);
     delete pixmapCache;
 }
 
@@ -192,7 +191,9 @@ bool ThemePrivate::useCache()
             if (!themeMetadataPath.isEmpty()) {
                 // now we record the theme version, if we can
                 const KPluginInfo pluginInfo(themeMetadataPath);
-                themeVersion = pluginInfo.version();
+                if (pluginInfo.isValid()) {
+                    themeVersion = pluginInfo.version();
+                }
                 if (!themeVersion.isEmpty()) {
                     cacheFile += QLatin1String("_v") + themeVersion;
                     currentCacheFileName = cacheFile + QLatin1String(".kcache");
@@ -217,7 +218,8 @@ bool ThemePrivate::useCache()
             QDir cacheDir(QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation));
             cacheDir.setNameFilters(QStringList({cacheFileBase}));
 
-            for (const QFileInfo &file : cacheDir.entryInfoList()) {
+            const auto files = cacheDir.entryInfoList();
+            for (const QFileInfo &file : files) {
                 if (currentCacheFileName.isEmpty() ||
                         !file.absoluteFilePath().endsWith(currentCacheFileName)) {
                     QFile::remove(file.absoluteFilePath());
@@ -242,8 +244,8 @@ bool ThemePrivate::useCache()
                 const QFileInfo metadataFileInfo(themeMetadataPath);
                 const QFileInfo iconThemeMetadataFileInfo(iconThemeMetadataPath);
 
-                cachesTooOld = (cacheFileInfo.lastModified().toTime_t() < metadataFileInfo.lastModified().toTime_t()) ||
-                        (cacheFileInfo.lastModified().toTime_t() < iconThemeMetadataFileInfo.lastModified().toTime_t());
+                cachesTooOld = (cacheFileInfo.lastModified().toSecsSinceEpoch() < metadataFileInfo.lastModified().toSecsSinceEpoch()) ||
+                        (cacheFileInfo.lastModified().toSecsSinceEpoch() < iconThemeMetadataFileInfo.lastModified().toSecsSinceEpoch());
             }
         }
 
@@ -266,7 +268,8 @@ bool ThemePrivate::useCache()
         QDir cacheDir(QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation));
         cacheDir.setNameFilters(QStringList({svgElementsFileNameBase + QLatin1Char('*')}));
 
-        for (const QFileInfo &file : cacheDir.entryInfoList()) {
+        const auto files = cacheDir.entryInfoList();
+        for (const QFileInfo &file : files) {
             if (!file.absoluteFilePath().endsWith(svgElementsFileName)) {
                 QFile::remove(file.absoluteFilePath());
             }
@@ -295,7 +298,7 @@ void ThemePrivate::onAppExitCleanup()
 {
     pixmapsToCache.clear();
     delete pixmapCache;
-    pixmapCache = 0;
+    pixmapCache = nullptr;
     cacheTheme = false;
 }
 
@@ -357,7 +360,7 @@ void ThemePrivate::discardCache(CacheTypes caches)
     } else {
         // This deletes the object but keeps the on-disk cache for later use
         delete pixmapCache;
-        pixmapCache = 0;
+        pixmapCache = nullptr;
     }
 
     cachedDefaultStyleSheet = QString();
@@ -368,7 +371,7 @@ void ThemePrivate::discardCache(CacheTypes caches)
         discoveries.clear();
         invalidElements.clear();
 
-        svgElementsCache = 0;
+        svgElementsCache = nullptr;
     }
 }
 
@@ -623,7 +626,7 @@ void ThemePrivate::saveSvgElementsCache()
 
 QColor ThemePrivate::color(Theme::ColorRole role, Theme::ColorGroup group) const
 {
-    const KColorScheme *scheme = 0;
+    const KColorScheme *scheme = nullptr;
 
     //Before 5.0 Plasma theme really only used Normal and Button
     //many old themes are built on this assumption and will break
@@ -725,23 +728,9 @@ void ThemePrivate::processContrastSettings(KConfigBase *metadata)
         cg = KConfigGroup(metadata, "ContrastEffect");
         backgroundContrastEnabled = cg.readEntry("enabled", false);
 
-        //if (backgroundContrastEnabled) {
-        // Make up sensible default values, based on the background color
-        // This works for a light theme -- lighting up the background
-        qreal _contrast = 0.3;
-        qreal _intensity = 1.9;
-        qreal _saturation = 1.7;
-
-        // If we're using a dark background color, darken the background
-        if (qGray(color(Plasma::Theme::BackgroundColor).rgb()) < 127) {
-            _contrast = 0.45;
-            _intensity = 0.45;
-            _saturation = 1.7;
-        }
-        backgroundContrast = cg.readEntry("contrast", _contrast);
-        backgroundIntensity = cg.readEntry("intensity", _intensity);
-        backgroundSaturation = cg.readEntry("saturation", _saturation);
-        //}
+        backgroundContrast = cg.readEntry("contrast", qQNaN());
+        backgroundIntensity = cg.readEntry("intensity", qQNaN());
+        backgroundSaturation = cg.readEntry("saturation", qQNaN());
     } else {
         backgroundContrastEnabled = false;
     }
@@ -791,7 +780,7 @@ void ThemePrivate::setThemeName(const QString &tempThemeName, bool writeSettings
     //qCDebug(LOG_PLASMA) << "we're going for..." << colorsFile << "*******************";
 
     if (colorsFile.isEmpty()) {
-        colors = 0;
+        colors = nullptr;
     } else {
         colors = KSharedConfig::openConfig(colorsFile);
     }
@@ -821,7 +810,7 @@ void ThemePrivate::setThemeName(const QString &tempThemeName, bool writeSettings
         while (!fallback.isEmpty() && !fallbackThemes.contains(fallback)) {
             fallbackThemes.append(fallback);
 
-            QString metadataPath(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1Literal(PLASMA_RELATIVE_DATA_INSTALL_DIR "/desktoptheme/") % theme % QLatin1Literal("/metadata.desktop")));
+            QString metadataPath(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1Literal(PLASMA_RELATIVE_DATA_INSTALL_DIR "/desktoptheme/") % fallback % QLatin1Literal("/metadata.desktop")));
             KConfig metadata(metadataPath, KConfig::SimpleConfig);
             KConfigGroup cg(&metadata, "Settings");
             fallback = cg.readEntry("FallbackTheme", QString());
